@@ -1,52 +1,34 @@
 """
 environment variable loading library for onboardme
 """
-from importlib.metadata import version as get_version
 import logging as log
 # for system data, environment data, and checking/joining paths
-from os import getenv, path, uname
+from os import path
 # rich helps pretty print everything
 from rich.prompt import Confirm
-from xdg import xdg_config_home
 import yaml
 
 # custom libs
+from .constants import OS, PWD, XDG_CONFIG_DIR
 from .console_logging import print_panel
 
 
-def load_cfg(config_file=""):
+def load_cfg(config_file: str) -> dict:
     """
-    load yaml config files for onboardme.
-    return dict
+    load yaml config files for onboardme
     """
     # make sure the path is valid
     if path.exists(config_file):
-        # make sure it's a yaml file extension
-        if config_file.endswith((".yaml", ".yml")):
-            with open(config_file, 'r') as yaml_file:
-                return yaml.safe_load(yaml_file)
-    else:
-        # print(f"Config file we got was not present: {yaml_config_file}")
-        return None
+        with open(config_file, 'r') as yaml_file:
+            return yaml.safe_load(yaml_file)
+    # return empty dict if there was no file
+    return {}
 
 
-# version of onboardme
-VERSION = get_version('onboardme')
-
-# pathing
-XDG_CONFIG_DIR = path.join(xdg_config_home(), 'onboardme')
-PWD = path.dirname(__file__)
-HOME_DIR = getenv("HOME")
-
 # defaults
 DEFAULTS = load_cfg(f"{PWD}/config/onboardme_config.yaml")
 USR_CONFIG_FILE = load_cfg(path.join(XDG_CONFIG_DIR, 'config.yaml'))
 
-# env
-SYSINFO = uname()
-# this will be something like ('Darwin', 'x86_64')
-OS = (SYSINFO.sysname, SYSINFO.machine)
-
 
 def check_os_support():
     """
@@ -69,7 +51,7 @@ def check_os_support():
                     "[cornflower_blue]Compatibility Check")
 
 
-def process_steps(steps=[], firewall=False, browser=False):
+def process_steps(steps: list, firewall=False, browser=False):
     """
     process which steps to run for which OS, which steps the user passed in,
     and then make sure dependent steps are always run.
@@ -99,7 +81,7 @@ def process_steps(steps=[], firewall=False, browser=False):
     return result_steps
 
 
-def sort_pkgmngrs(package_managers_list=[]):
+def sort_pkgmngrs(package_managers_list: list) -> list:
     """
     make sure the package managers are in the right order 🤦
     e.g. apt installs snap and flatpak, so niether can be run until apt is run
@@ -118,7 +100,8 @@ def sort_pkgmngrs(package_managers_list=[]):
     return reordered_list
 
 
-def fill_in_defaults(defaults={}, user_config={}, always_prefer_default=False):
+def fill_in_defaults(defaults: dict, user_config: dict,
+                     always_prefer_default=False) -> dict:
     """
     Compares/Combines a default dict and another dict. Prefer default values
     only if the value is empty in the second dict. Then return new dict.
